import React from "react";
import NavigationButtons from "@/components/NavigationButtons";
import { Book, Chapter } from "@/lib/types";
import { fetchBookById } from "@/lib/api";
import Head from "next/head";
export type paramsType = Promise<{ bookId: string; chapterId: string }>;

// Dynamic page component
export default async function ChapterPage(props: { params: paramsType}) {
    const { bookId, chapterId } = await props.params;

    let book: Book;
    try{
        book = await fetchBookById(bookId);
    }
    catch (error) {
        console.error(error);
        return (    
            <>
            <Head>
                <title>Chapter not found</title>
                <meta name="description" content="Chapter not found" />
            </Head>
                <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
                    <div dangerouslySetInnerHTML={{ __html: '<center><h1> Chapter not found !</h1></center>' }}></div>
                <NavigationButtons bookId={bookId} documentId={chapterId} prevChapter={""} nextChapter={""} />
                </div>
            </>
        )
    }

    const chapters :Chapter[] = book.chapters;
    const sorted_chapters:Chapter[] = chapters.sort((a, b) => a.number - b.number);
    const current_chapter = sorted_chapters.find((chapter) => chapter.documentId === chapterId) || null;
    const next_chapter = current_chapter ? sorted_chapters.find((chapter) => chapter.number === current_chapter.number + 1)?.documentId || "" : "";
    const prev_chapter = current_chapter ? sorted_chapters.find((chapter) => chapter.number === current_chapter.number - 1)?.documentId || "" : "";

    if(current_chapter === null){
        return (    
            <>
            <Head>
                <title>Chapter not found</title>
                <meta name="description" content="Chapter not found" />
            </Head>
                <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
                    <div dangerouslySetInnerHTML={{ __html: '<center><h1> Chapter not found !</h1></center>' }}></div>
                <NavigationButtons bookId={bookId} documentId={chapterId} prevChapter={""} nextChapter={""} />
                </div>
            </>
        )
    }
        
    return (
        <>
        <Head>
            <title>{book.title} - Chapter {current_chapter?.number}</title>
            <meta name="description" content={book.description} />
        </Head>
            <div className="prose dark:prose-invert mx-auto p-6 bg-white dark:bg-gray-800 shadow-md rounded-lg mt-4">
            <NavigationButtons bookId={bookId} documentId={chapterId} prevChapter={prev_chapter} nextChapter={next_chapter} />
                <div className="pt-4" dangerouslySetInnerHTML={{ __html: current_chapter.content }}></div>
        
                <NavigationButtons bookId={bookId} documentId={chapterId} prevChapter={prev_chapter} nextChapter={next_chapter}/>
            </div>
        </>
    );
}